@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::P;
-$Time::P::VERSION = '0.013';
+$Time::P::VERSION = '0.014';
 # ABSTRACT: Parse times from strings.
 
 use Carp qw/ croak /;
@@ -317,7 +317,7 @@ Time::P - Parse times from strings.
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -351,7 +351,7 @@ C<$fmt> is the format specifier used to parse the C<$str>. If it can't match C<$
 
 =item C<< locale => $locale >>
 
-C<$locale> is an optional boolean flag which defaults to C<C>. It is used to determine how the format specifiers C<%a>, C<%A>, C<%b>, C<%B>, C<%c>, C<%p>, and C<%r> match. See L<Format Specifiers> for more details.
+C<$locale> is an optional parameter which defaults to C<C>. It is used to determine how the format specifiers C<%a>, C<%A>, C<%b>, C<%B>, C<%c>, C<%p>, and C<%r> match. See L<Format Specifiers> for more details.
 
 =item C<< strict => $strict >>
 
